#
# Copyright 2019-2024 SUSE LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#    https://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#


Name:           prometheus-ha_cluster_exporter
# Version will be processed via set_version source service
Version:        1.4.0+git.2.1734607520.57bbe75
Release:        1.2
Summary:        Prometheus exporter for Pacemaker HA clusters metrics
License:        Apache-2.0
Group:          System/Monitoring
URL:            https://github.com/ClusterLabs/ha_cluster_exporter
Source:         %{name}-%{version}.tar.gz
Source1:        vendor.tar.gz
BuildRequires:  golang(API) >= 1.23
Requires(post): %fillup_prereq
Provides:       ha_cluster_exporter = %{version}-%{release}
Provides:       prometheus(ha_cluster_exporter) = %{version}-%{release}
ExclusiveArch:  aarch64 x86_64 ppc64le s390x

#Compat macro for new _fillupdir macro introduced in Nov 2017
%if ! %{defined _fillupdir}
  %define _fillupdir /var/adm/fillup-templates
%endif

%description
Prometheus exporter for Pacemaker HA clusters metrics

%prep
%setup -q            # unpack project sources
%setup -q -T -D -a 1 # unpack go dependencies in vendor.tar.gz, which was prepared by the source services

%define shortname ha_cluster_exporter

%build
%ifarch s390x
  export CGO_ENABLED=1
%else
  export CGO_ENABLED=0
%endif
go build -mod=vendor \
         -buildmode=pie \
         -ldflags="-s -w -X github.com/prometheus/common/version.Version=%{version}" \
         -o %{shortname}

%install

# Install the binary.
install -D -m 0755 %{shortname} "%{buildroot}%{_bindir}/%{shortname}"

# Install the systemd unit
install -D -m 0644 %{shortname}.service %{buildroot}%{_unitdir}/%{name}.service

# Install the environment file
install -D -m 0644 %{shortname}.sysconfig %{buildroot}%{_fillupdir}/sysconfig.%{name}

# Install compat wrapper for legacy init systems
install -Dd -m 0755 %{buildroot}%{_sbindir}
ln -s /usr/sbin/service %{buildroot}%{_sbindir}/rc%{name}

# Install supportconfig plugin
install -D -m 755 supportconfig-ha_cluster_exporter %{buildroot}%{_prefix}/lib/supportconfig/plugins/%{shortname}

%pre
%service_add_pre %{name}.service

%post
%service_add_post %{name}.service
%fillup_only -n %{name}

%preun
%service_del_preun %{name}.service

%postun
%service_del_postun %{name}.service

%files
%doc *.md
%doc doc/*
%if 0%{?suse_version} >= 1500
%license LICENSE
%else
%doc LICENSE
%endif
%{_bindir}/%{shortname}
%{_unitdir}/%{name}.service
%{_fillupdir}/sysconfig.%{name}
%{_sbindir}/rc%{name}
%dir %{_prefix}/lib/supportconfig
%dir %{_prefix}/lib/supportconfig/plugins
%{_prefix}/lib/supportconfig/plugins/%{shortname}

%changelog
* Tue Dec 17 2024 UTC - shap-staff@suse.de
- Release 1.4.0
  [#]# What's Changed
  * add support to show overall cluster maintenance mode by @scrusanhrt in https://github.com/ClusterLabs/ha_cluster_exporter/pull/260
  * add supportconfig plugin (jsc#PED-2560) by @angelabriel in https://github.com/ClusterLabs/ha_cluster_exporter/pull/250
  * update the CI workflow
  * change default OBS development project
  * bump required Go version to 1.23
  * fix corosync collector parser when using IPv6 hostnames (#245)
  [#]## Dependabot updates
  * Bump github.com/prometheus/client_model from 0.3.0 to 0.4.0 by @dependabot in https://github.com/ClusterLabs/ha_cluster_exporter/pull/224
  * Bump github.com/prometheus/client_golang from 1.15.0 to 1.15.1 by @dependabot in https://github.com/ClusterLabs/ha_cluster_exporter/pull/225
  * Bump github.com/prometheus/common from 0.42.0 to 0.44.0 by @dependabot in https://github.com/ClusterLabs/ha_cluster_exporter/pull/226
  * Bump github.com/spf13/viper from 1.15.0 to 1.16.0 by @dependabot in https://github.com/ClusterLabs/ha_cluster_exporter/pull/227
  * Bump github.com/stretchr/testify from 1.8.2 to 1.8.4 by @dependabot in https://github.com/ClusterLabs/ha_cluster_exporter/pull/228
  * Bump github.com/prometheus/client_golang from 1.15.1 to 1.16.0 by @dependabot in https://github.com/ClusterLabs/ha_cluster_exporter/pull/230
  * Bump github.com/prometheus/client_golang from 1.16.0 to 1.17.0 by @dependabot in https://github.com/ClusterLabs/ha_cluster_exporter/pull/234
  * Bump golang.org/x/net from 0.10.0 to 0.17.0 by @dependabot in https://github.com/ClusterLabs/ha_cluster_exporter/pull/235
  * Bump github.com/prometheus/common from 0.44.0 to 0.55.0 by @dependabot in https://github.com/ClusterLabs/ha_cluster_exporter/pull/259
  * Bump github.com/spf13/viper from 1.16.0 to 1.19.0 by @dependabot in https://github.com/ClusterLabs/ha_cluster_exporter/pull/258
  * Bump actions/download-artifact from 3 to 4.1.7 in /.github/workflows by @dependabot in https://github.com/ClusterLabs/ha_cluster_exporter/pull/265
  * Bump github.com/prometheus/client_golang from 1.19.1 to 1.20.2 by @dependabot in https://github.com/ClusterLabs/ha_cluster_exporter/pull/262
  * Bump github.com/prometheus/common from 0.55.0 to 0.59.1 by @dependabot in https://github.com/ClusterLabs/ha_cluster_exporter/pull/266
  * Bump github.com/prometheus/client_golang from 1.20.2 to 1.20.4 by @dependabot in https://github.com/ClusterLabs/ha_cluster_exporter/pull/267
  * Bump github.com/prometheus/client_golang from 1.20.4 to 1.20.5 by @dependabot in https://github.com/ClusterLabs/ha_cluster_exporter/pull/268
  * Bump github.com/stretchr/testify from 1.9.0 to 1.10.0 by @dependabot in https://github.com/ClusterLabs/ha_cluster_exporter/pull/269
  * Bump golang.org/x/crypto from 0.26.0 to 0.31.0 in the go_modules group by @dependabot in https://github.com/ClusterLabs/ha_cluster_exporter/pull/270
  [#]# New Contributors
  * @angelabriel made their first contribution in https://github.com/ClusterLabs/ha_cluster_exporter/pull/250
  * @scrusanhrt made their first contribution in https://github.com/ClusterLabs/ha_cluster_exporter/pull/260
  * *Full Changelog**: https://github.com/ClusterLabs/ha_cluster_exporter/compare/1.3.3...1.4.0
* Mon May 29 2023 UTC - shap-staff@suse.de
- Release 1.3.3
  [#]# What's Changed
  * bump go version to 1.20 (bnc#1208296)
  * *Full Changelog**: https://github.com/ClusterLabs/ha_cluster_exporter/compare/1.3.2...1.3.3
* Tue May  2 2023 UTC - shap-staff@suse.de
- Release 1.3.2
  [#]# What's Changed
  * fine tune regexp and test case with tabs by @stefanotorresi in https://github.com/ClusterLabs/ha_cluster_exporter/pull/216
  * Bump github.com/stretchr/testify from 1.8.1 to 1.8.2 by @dependabot in https://github.com/ClusterLabs/ha_cluster_exporter/pull/213
  * make sbd config devices parser more resilient by @stefanotorresi in https://github.com/ClusterLabs/ha_cluster_exporter/pull/221
  * Update Go dependencies and bump minimum Go version to 1.17 by @stefanotorresi in https://github.com/ClusterLabs/ha_cluster_exporter/pull/222
  * *Full Changelog**: https://github.com/ClusterLabs/ha_cluster_exporter/compare/1.3.1...1.3.2
* Fri Feb 10 2023 UTC - shap-staff@suse.de
- Release 1.3.1
  [#]# Changed
  * Brought GitHub Actions config and Makefile up to speed.
  * Bump github.com/prometheus/client_golang from 1.12.2 to 1.14.0 by @dependabot in https://github.com/ClusterLabs/ha_cluster_exporter/pull/208
  * Bump github.com/stretchr/testify from 1.7.1 to 1.8.1 by @dependabot in https://github.com/ClusterLabs/ha_cluster_exporter/pull/211
  * Bump github.com/prometheus/exporter-toolkit from 0.7.1 to 0.7.3 by @dependabot in https://github.com/ClusterLabs/ha_cluster_exporter/pull/207 (fixes bnc#1208046 CVE-2022-46146)
  * *Full Changelog**: https://github.com/ClusterLabs/ha_cluster_exporter/compare/1.3.0...1.3.1
* Tue May 24 2022 UTC - shap-staff@suse.de
- Release 1.3.0
  [#]# Added
  - TLS and basic auth support (#200)
  - sysconfig file now available to override systemd unit CLI arguments (#200)
  [#]# Changed
  - **Deprecated**: Some CLI flags were deprecated in favour of new ones according to upstream conventions (#200)
  - Boilerplate now uses the Prometheus Exporter Toolkit (#200)
  - Rename `master` branch to `main`
  - Rename dashboard provider subpackage (#196)
* Fri May 28 2021 UTC - shap-staff@suse.de
- Release 1.2.3
  [#]# Changed
  - Compress GitHub artifacts (#195)
  [#]# Fixed
  - Fix cloned resource collection once and for all (#194)
  [#]# Removed
  - Remove the `make download` target, which was mostly useless. (#194)
* Wed May 12 2021 UTC - shap-staff@suse.de
- Release 1.2.2
  [#]# Added
  - Add parsing of the `crm_config` node in the CIB parser. (#190)
  [#]# Changed
  - Update the minimum required Go version to 1.14. (#192)
  [#]# Fixed
  - Avoid duplicate metric recording errors for non-running OCFS resources. (#191)
* Wed Dec  2 2020 UTC - shap-staff@suse.de
- Release 1.2.1
  [#]# Fixed
  - Remove Pacemaker dependency from systemd unit (#180)
* Fri Sep 11 2020 UTC - shap-staff@suse.de
- Release 1.2.0
  [#]# Added
  - Implement SBD watchdog and msgwait timeout metrics (#174)
  [#]# Fixed
  - Handle correctly corosync membership parsing with qdevice enabled (#172)
* Mon Jul 13 2020 UTC - shap-staff@suse.de
- Release 1.1.0
  [#]# Added
  - Support for Corosync v3 (#156)
  - `--version` CLI flag (#158 #168)
  - Grafana dashboards (#160 #166)
  - New metrics for Pacemaker node attributes (#167)
  - New metrics for instrumentation of the exporter itself (#169)
  [#]# Changed
  - `--enable-timestamps` CLI flag and config option have been marked as deprecated (#158)
  - Migrated CI from Travis to GitHub Actions (#163)
  - Update and improve documentation (#164 #165)
  [#]# Fixed
  - Fix `corosync-quorumtool` parsing in Corosync v2.3.6 (#157)
* Mon May 18 2020 Stefano Torresi <stefano.torresi@suse.com>
- Backport to SLE12SP3 and SLE15. (jsc#SLE-10902, jsc#SLE-10903, jsc#ECO-817, jsc#ECO-818)
* Mon May  4 2020 UTC - shap-staff@suse.de
- Release 1.0.1
  [#]# Fixed
  - Corosync membership parsing (#154)
* Mon May  4 2020 UTC - shap-staff@suse.de
- Release 1.0.0
  [#]# Added
  - New `group` and `clone` labels for `ha_cluster_pacemaker_resources` metric. (#145, #153)
  - New `ha_cluster_corosync_member_votes` metric and new labels for `ha_cluster_corosync_rings`. (#151)
  [#]# Fixed
  - **BC Break** - `ha_cluster_pacemaker_nodes` and `ha_cluster_pacemaker_resources` now report `0` values instead of disappearing. (#152)
  - Grouped resources in stopped status are now tracked correctly. (#145)
  - Error handling during collection cycles is more consistent across the board. (#148)
  - Corosync v3 is now explicitly reported as not being currently supported. (#149)
  [#]# Removed
  - Unnecessary file I/O in DRBD collector. (#150)
* Tue Mar 31 2020 UTC - shap-staff@suse.de
- Release 1.0.0rc1
  [#]# Added
  - Resource metrics now have an `agent` label (#143)
  [#]# Changed
  - Go runtime debug metrics are now opt-in (#142)
  - Overhauled Travis CI config to implement new OBS continuous delivery (#144)
  - Updated some documentation and boilerplate (3de9c59)
* Thu Mar 12 2020 UTC - shap-staff@suse.de
- Release 1.0.0beta8
  [#]# Changed
  - Reduced log verbosity of collect cycles to `DEBUG` level. (#137)
  - Moved OBS related files to `packaging/obs`. (#139)
  [#]# Fixed
  - Pacemaker CIB parsing errors with some time values. (#138)
  - Regression in CI changelog generator. (#136)
* Fri Feb 28 2020 UTC - shap-staff@suse.de
- Release 1.0.0beta7
  [#]# Changed
  - Refactored project structure by using Go packages (#131).
  - Refactored Pacemaker collector and separate XML parsing from the metrics collection (#132).
  - The open-source software license has been changed from GPLv3 to Apache 2.0. (#133)
  - The RPM build no longer uses PIE, which made Go platform compatibility potentially problematic. (#133)
  [#]# Fixed
  - Stopped resources are now tracked correctly. (#134)
  - A few edge cases previously uncovered in the CI pipeline are now handled correctly. (#135)
* Wed Feb 12 2020 UTC - shap-staff@suse.de
- Release 1.0.0beta6
  [#]# Changed
  - Revert full Source url usage and reinstate OBS source service in the build pipeline (#129)
* Tue Feb 11 2020 UTC - shap-staff@suse.de
- Release 1.0.0beta5
  [#]# Fixed
  - Source url in spec file (#128)
* Tue Feb 11 2020 UTC - shap-staff@suse.de
- Release 1.0.0beta4
  [#]# Changed
  - Use a full source url in the spec file (#127)
* Mon Feb 10 2020 UTC - shap-staff@suse.de
- Release 1.0.0beta3
  [#]# Added
  - Copyright notice to README and RPM spec file. (#126)
* Mon Feb 10 2020 Stefano Torresi <stefano.torresi@suse.com>
- SR to Factory and SLES 15 SP2 (jsc#SLE-10545)
* Wed Feb  5 2020 UTC - shap-staff@suse.de
- Release 1.0.0beta2
  [#]# Changed
  - **BC Break**: Default TCP listening port changed again from 9964 to 9664 due to a typo. (#124)
  - **BC Break**: Many refactorings to multiple metrics that didn't comply with Prometheus vetting process. (#123)
* Tue Feb  4 2020 UTC - shap-staff@suse.de
- Release 1.0.0-beta
  [#]# Changed
  - **BC Break** - Metrics timestamps are now opt-in and disabled by default. The old behaviour can be kept via the `--enable-timestamps` CLI flag / config option. (#118)
  - **BC Break** - Default TCP listening port changed from 9002 to 9964. The old behaviour can be kept via the `--port` CLI flags / config option. (#122)
* Fri Dec 13 2019 UTC - shap-staff@suse.de
- Release 0.4.0
  [#]# Added
  - Added more new DRBD metrics (#106 #108)
  [#]# Changed
  - OBS builds don't reuse the binaries built in Travis anymore, due to compliance requirements (#105)
  [#]# Fixed
  - Various grammar/typos in the docs (#103, #104, #106)
  [#]# Removed
  - Useless warning about missing DRBD split-brain notifications directory (#110)
* Thu Nov 28 2019 UTC - shap-staff@suse.de
- Release 0.3.0
  [#]# Added
  - Brand new `ha_cluster_drbd_split_brain` metric (#100)
  - Travis "Build & release" job automatically publishes built assets to GH releases and deploys tags in OBS. (#102)
  [#]# Changed
  - **BC Break** - Refactor Pacemaker location constraints metric (#99)
  [#]# Fixed
  - DRBD default path now corresponds with the DBRD packages of the distros we use and support (#101)
* Fri Nov 15 2019 stefano.torresi@suse.com
- Update to version 0.2.0:
  * make drbd resource label usage consistent
  * make the resource and node name/id labels match across all the metrics that have it
  * document possible values
  * comment regex usage
  * add test case for edge case not previously covered
  * update metrics doc
  * add ha_cluster_sbd_devices_total metric
  * minor readme fixes
  * make collector initalization error handling cleaner
  * add /usr/etc to the scanned config dirs
  * readme changes
  * fix typo in config example
  * make more clear that what is being added are directories
  * improve help
  * initialize flags in init instead of main
  * integrate config with cli flags
  * rename var for consistency
  * add sample config and run go fmt
  * use an alias for better clarity
  * add static configuration support via spf13/viper library
  * fix config_last_change pacemaker metric due to Prometheus limitations
  * Improves DRBD Percent Sync Doc (Float values).
  * Fix DRBD test message
  * Change DRBD percent from int to Float
* Thu Oct 31 2019 dmaiocchi@suse.com
- Update to version 0.1.0:
  * add doc
  * Update metrics on constraints
  * check for binary existence
  * Add -address listen, log -level flag
  * Implement constraint ban metric
  * Implement Delta metric percentInSync
  * Update pacemaker_metrics.go
  * Implement metric and doc
  * Add needed struct and test parsing xml
  * Implement skeleton and fake data
  * Implement Migration threshold metric
  * Add landing page to exporter
  * Add documentation about metric
  * Implement failcount metric population with data
  * Implement metric structs and needed tests
  * add testdata
* Fri Oct 25 2019 stefano.torresi@suse.com
- Update to version 0.0.9:
    [#]# Added
  - All the metrics are now timestamped (#67)
  - New `ha_cluster_pacemaker_stonith_enabled` metric (#68)
  - Comprehensive [metrics documentation](https://github.com/ClusterLabs/ha_cluster_exporter/blob/0.0.9/doc/metrics.md)
  - RPM package spec and SystemD unit are now in the repo rather than in the OBS package.
    [#]# Changed
  - Extensive refactoring to implement `prometheus.Collector` API (#66)
  - Various metrics and their labels were renamed (#61, #62)
  - Removed Go vendoring mode (#76)
    [#]# Fixed
  - Metrics no longer need to be reset (#60)
  - TravisCI configuration (#74)
* Fri Oct 18 2019 Dario Maiocchi <dmaiocchi@suse.com>
- update to 0.0.8 Release Github: DRBD Metrics and other minor improvements
* Wed Oct  2 2019 Dario Maiocchi <dmaiocchi@suse.com>
- remove user and group from systemd unit file. (cause breakage on exporter)
* Wed Oct  2 2019 Dario Maiocchi <dmaiocchi@suse.com>
- update to 0.0.7 Releases Github: SBD metrics
* Mon Sep 30 2019 Dario Maiocchi <dmaiocchi@suse.com>
-  update to 0.0.6 Rel GitHub: corosync metrics
* Wed Sep 18 2019 Dario Maiocchi <dmaiocchi@suse.com>
- update to 0.0.5 Released GitHub version. Metrics improvements
* Tue Sep 17 2019 Ayoub Belarbi <abelarbi@suse.de>
- Version bump to 0.0.4
- Start prometheus-ha_cluster_exporter systemd service after pacemaker service
* Tue Sep 17 2019 Ayoub Belarbi <abelarbi@suse.de>
- fix source file name
* Tue Sep 17 2019 Dario Maiocchi <dmaiocchi@suse.com>
- Add new version model fine grained. 0.0.3  Version. Add logging for systemd
* Tue Sep 17 2019 Dario Maiocchi <dmaiocchi@suse.com>
- Adapt systemd unit file to ha_exporter
* Tue Sep 17 2019 Ayoub Belarbi <abelarbi@suse.de>
- Match tar file name with package name
* Mon Sep 16 2019 Dario Maiocchi <dmaiocchi@suse.com>
- add 0.1 version of ha_cluster exporter
